]> git.ipfire.org Git - thirdparty/grub.git/commitdiff
Typo fixes in comments and variable names.
authorproski <proski@localhost>
Sun, 30 Dec 2007 08:52:06 +0000 (08:52 +0000)
committerproski <proski@localhost>
Sun, 30 Dec 2007 08:52:06 +0000 (08:52 +0000)
39 files changed:
disk/raid.c
fs/ext2.c
fs/hfs.c
fs/hfsplus.c
fs/iso9660.c
fs/jfs.c
fs/ufs.c
include/grub/efi/api.h
include/grub/elf.h
include/grub/i386/pc/vbe.h
include/grub/i386/time.h
include/grub/video.h
io/gzio.c
kern/env.c
kern/i386/pc/startup.S
kern/misc.c
kern/mm.c
kern/powerpc/ieee1275/cmain.c
kern/powerpc/ieee1275/openfw.c
kern/sparc64/ieee1275/openfw.c
normal/execute.c
normal/lexer.c
normal/menu_entry.c
normal/parser.y
normal/script.c
partmap/acorn.c
partmap/sun.c
term/gfxterm.c
term/i386/pc/serial.c
term/i386/pc/vesafb.c
util/biosdisk.c
util/genmoddep.c
util/i386/efi/grub-install.in
util/i386/pc/grub-install.in
util/powerpc/ieee1275/grub-install.in
util/update-grub.in
video/i386/pc/vbe.c
video/readers/tga.c
video/video.c

index 663bab8822727915df91e38c9d369d6a1c8e21e2..d5015e047e4585c905c4cbc13408388c0a85b628 100644 (file)
@@ -162,7 +162,7 @@ grub_raid_read (grub_disk_t disk, grub_disk_addr_t sector,
              read_size = size;
 
            /* Check whether the sector was aligned on a chunk size
-              bounday. If this isn't the case, it's the first read
+              boundary. If this isn't the case, it's the first read
               and the next read should be set back to start of the
               boundary.  */
            grub_divmod64 (read_sector, array->chunk_size, &i);
@@ -282,7 +282,7 @@ grub_raid_read (grub_disk_t disk, grub_disk_addr_t sector,
              read_size = size;
 
            /* Check whether the sector was aligned on a chunk size
-              bounday. If this isn't the case, it's the first read
+              boundary. If this isn't the case, it's the first read
               and the next read should be set back to start of the
               boundary.  */
            grub_divmod64 (read_sector, array->chunk_size, &i);
index 1aeaa9481ec4f3f45dc4a1e26faefdabb8b7974c..ec665827b1e8aa94387a824c777cb8a58ed0c94e 100644 (file)
--- a/fs/ext2.c
+++ b/fs/ext2.c
@@ -21,7 +21,7 @@
 #define        EXT2_MAGIC              0xEF53
 /* Amount of indirect blocks in an inode.  */
 #define INDIRECT_BLOCKS                12
-/* Maximum lenght of a pathname.  */
+/* Maximum length of a pathname.  */
 #define EXT2_PATH_MAX          4096
 /* Maximum nesting of symlinks, used to prevent a loop.  */
 #define        EXT2_MAX_SYMLINKCNT     8
@@ -146,7 +146,7 @@ struct grub_ext2_inode
       grub_uint32_t dir_blocks[INDIRECT_BLOCKS];
       grub_uint32_t indir_block;
       grub_uint32_t double_indir_block;
-      grub_uint32_t tripple_indir_block;
+      grub_uint32_t triple_indir_block;
     } blocks;
     char symlink[60];
   };
@@ -251,11 +251,11 @@ grub_ext2_read_block (grub_fshelp_node_t node, int fileblock)
       
       blknr = grub_le_to_cpu32 (indir[rblock % perblock]);
     }
-  /* Tripple indirect.  */
+  /* triple indirect.  */
   else
     {
       grub_error (GRUB_ERR_NOT_IMPLEMENTED_YET,
-                 "ext2fs doesn't support tripple indirect blocks");
+                 "ext2fs doesn't support triple indirect blocks");
       blknr = -1;
     }
 
index be129b4cd56fa3abbff3acf303167b4930e26f7a..e8e9c3e50d57d300af4e5d32c5c90b076a9e0bfa 100644 (file)
--- a/fs/hfs.c
+++ b/fs/hfs.c
@@ -43,7 +43,7 @@ enum
     GRUB_HFS_FILETYPE_FILE = 2
   };
 
-/* A node desciptor.  This is the header of every node.  */
+/* A node descriptor.  This is the header of every node.  */
 struct grub_hfs_node
 {
   grub_uint32_t next;
index c3e57a4ca34a7741b2e918b51db8f6d32a4ba053..fe7253945f16e43ee45712a6457277018ef20653 100644 (file)
@@ -303,7 +303,7 @@ grub_hfsplus_read_block (grub_fshelp_node_t node, int fileblock)
       blk = grub_hfsplus_find_block (extents, &blksleft);
 
       /* The previous iteration of this loop allocated memory.  The
-        code above used this memory, it can be free'ed now.  */
+        code above used this memory, it can be freed now.  */
       grub_free (nnode);
       nnode = 0;
       
@@ -505,7 +505,7 @@ grub_hfsplus_cmp_catkey (struct grub_hfsplus_key *keya,
   if (diff)
     return diff; 
 
-  /* Change the filename in keya so the endianess is correct.  */
+  /* Change the filename in keya so the endianness is correct.  */
   for (i = 0; i < grub_be_to_cpu16 (catkey_a->namelen); i++)
     catkey_a->name[i] = grub_be_to_cpu16 (catkey_a->name[i]);
 
@@ -521,7 +521,7 @@ grub_hfsplus_cmp_catkey (struct grub_hfsplus_key *keya,
 
   grub_free (filename);
 
-  /* The endianess was changed to host format, change it back to
+  /* The endianness was changed to host format, change it back to
      whatever it was.  */
   for (i = 0; i < grub_be_to_cpu16 (catkey_a->namelen); i++)
     catkey_a->name[i] = grub_cpu_to_be16 (catkey_a->name[i]);
@@ -606,7 +606,7 @@ grub_hfsplus_btree_iterate_node (struct grub_hfsplus_btree *btree,
 /* Lookup the node described by KEY in the B+ Tree BTREE.  Compare
    keys using the function COMPARE_KEYS.  When a match is found,
    return the node in MATCHNODE and a pointer to the data in this node
-   in KEYOFFSET.  MATCHNODE should be free'ed by the caller.  */
+   in KEYOFFSET.  MATCHNODE should be freed by the caller.  */
 static grub_err_t
 grub_hfsplus_btree_search (struct grub_hfsplus_btree *btree,
                           struct grub_hfsplus_key_internal *key,
@@ -661,7 +661,7 @@ grub_hfsplus_btree_search (struct grub_hfsplus_btree *btree,
            {
              grub_uint32_t *pointer;
 
-             /* The place where the key could've been found didn't
+             /* The place where the key could have been found didn't
                 contain the key.  This means that the previous match
                 is the one that should be followed.  */
              if (compare_keys (currkey, key) > 0)
@@ -943,7 +943,7 @@ grub_hfsplus_label (grub_device_t device __attribute__((unused))
   /* XXX: It's not documented how to read a label.  */
   return grub_error (GRUB_ERR_NOT_IMPLEMENTED_YET,
                     "reading the label of a HFS+ "
-                    "partiton is not implemented");
+                    "partition is not implemented");
 }
 
 \f
index 325068b06872ab1f10098059c6862d5718c83a25..15ce51d26a23ecae05a0365196342bf0814bdc59 100644 (file)
@@ -283,13 +283,13 @@ grub_iso9660_mount (grub_disk_t disk)
   /* Test if the SUSP protocol is used on this filesystem.  */
   if (grub_strncmp ((char *) entry->sig, "SP", 2) == 0)
     {
-      /* The 2nd data byte stored how many bytes are skipped everytime
+      /* The 2nd data byte stored how many bytes are skipped every time
         to get to the SUA (System Usage Area).  */
       data->susp_skip = entry->data[2];
       entry = (struct grub_iso9660_susp_entry *) ((char *) entry + entry->len);
       
       /* Iterate over the entries in the SUA area to detect
-        entensions.  */
+        extensions.  */
       if (grub_iso9660_susp_iterate (data,
                                     (grub_le_to_cpu32 (data->voldesc.rootdir.first_sector)
                                      << GRUB_ISO9660_LOG2_BLKSZ),
index be489b9b2e992df04c76187eef8c1ccf8035fe36..8a027aec8f110302c4f31f0f05bd2d1e44ba47bc 100644 (file)
--- a/fs/jfs.c
+++ b/fs/jfs.c
@@ -478,7 +478,7 @@ grub_jfs_getent (struct grub_jfs_diropen *diro)
     {
       unsigned int next;
       
-      /* If the inode contains the entrie tree or if this was the last
+      /* If the inode contains the entry tree or if this was the last
         node, there is nothing to read.  */
       if ((diro->inode->file.tree.flags & GRUB_JFS_TREE_LEAF)
          || !grub_le_to_cpu64 (diro->dirpage->header.nextb))
index ba7bfb03f7de94073f2cb06da75435a1c225c18b..917d9a295bc4ad8f04eb9d9b3229f6d895e07547 100644 (file)
--- a/fs/ufs.c
+++ b/fs/ufs.c
@@ -231,7 +231,7 @@ grub_ufs_get_file_block (struct grub_ufs_data *data, unsigned int blk)
 
 
   grub_error (GRUB_ERR_NOT_IMPLEMENTED_YET,
-             "ufs does not support tripple indirect blocks");
+             "ufs does not support triple indirect blocks");
   return 0;
 }
 
index c7d0c123ae0b80a92b7f38888b2b119cc2b2664e..6c29753371719d49d78f2a314e231b4ec773ddac 100644 (file)
@@ -711,7 +711,7 @@ struct grub_efi_boot_services
   (*reinstall_protocol_interface) (grub_efi_handle_t handle,
                                   grub_efi_guid_t *protocol,
                                   void *old_interface,
-                                  void *new_inteface);
+                                  void *new_interface);
   
   grub_efi_status_t
   (*uninstall_protocol_interface) (grub_efi_handle_t handle,
index 91f1f3ccd7037b6ce25c61dd756f0a61e009f0bc..9aec816c7d33d64cc20776349a6073c318a40fdc 100644 (file)
@@ -799,7 +799,7 @@ typedef struct
 #define        VER_NDX_LORESERVE       0xff00  /* Beginning of reserved entries.  */
 #define        VER_NDX_ELIMINATE       0xff01  /* Symbol is to be eliminated.  */
 
-/* Auxialiary version information.  */
+/* Auxiliary version information.  */
 
 typedef struct
 {
index c00d7d019a5ce735e130845bab3f66f1f90c8740..3a301cb148e43972e2f849278f11e4668df05c84 100644 (file)
@@ -39,8 +39,8 @@
    Please refer to VESA BIOS Extension 3.0 Specification for more descriptive
    meanings of following structures and how they should be used.
 
-   I have tried to maintain field name comatibility against specification 
-   while following naming convetions used in GRUB.  */
+   I have tried to maintain field name compatibility against specification
+   while following naming conventions used in GRUB.  */
 
 typedef grub_uint32_t grub_vbe_farptr_t;
 typedef grub_uint32_t grub_vbe_physptr_t;
@@ -68,7 +68,7 @@ struct grub_vbe_info_block
 
 struct grub_vbe_mode_info_block
 {
-  /* Mandory information for all VBE revisions.  */
+  /* Mandatory information for all VBE revisions.  */
   grub_uint16_t mode_attributes;
   grub_uint8_t win_a_attributes;
   grub_uint8_t win_b_attributes;
@@ -79,7 +79,7 @@ struct grub_vbe_mode_info_block
   grub_vbe_farptr_t win_func_ptr;
   grub_uint16_t bytes_per_scan_line;
 
-  /* Mandory information for VBE 1.2 and above.  */
+  /* Mandatory information for VBE 1.2 and above.  */
   grub_uint16_t x_resolution;
   grub_uint16_t y_resolution;
   grub_uint8_t x_char_size;
@@ -103,12 +103,12 @@ struct grub_vbe_mode_info_block
   grub_uint8_t rsvd_field_position;
   grub_uint8_t direct_color_mode_info;
 
-  /* Mandory information for VBE 2.0 and above.  */
+  /* Mandatory information for VBE 2.0 and above.  */
   grub_vbe_physptr_t phys_base_addr;
   grub_uint32_t reserved2;
   grub_uint16_t reserved3;
 
-  /* Mandory information for VBE 3.0 and above.  */
+  /* Mandatory information for VBE 3.0 and above.  */
   grub_uint16_t lin_bytes_per_scan_line;
   grub_uint8_t bnk_number_of_image_pages;
   grub_uint8_t lin_number_of_image_pages;
@@ -148,7 +148,7 @@ struct grub_vbe_palette_data
   grub_uint8_t blue;
   grub_uint8_t green;
   grub_uint8_t red;
-  grub_uint8_t aligment;
+  grub_uint8_t alignment;
 } __attribute__ ((packed));
 
 /* Prototypes for kernel real mode thunks.  */
@@ -220,7 +220,7 @@ struct grub_video_render_target
     unsigned int height;
   } viewport;
 
-  /* Indicates wether the data has been allocated by us and must be freed
+  /* Indicates whether the data has been allocated by us and must be freed
      when render target is destroyed.  */
   int is_allocated;
 
index a09d793d272b5b7d1a2a4833438767ca8417492f..842882cf24914acf9c614c77c74712a4e4d0af16 100644 (file)
@@ -22,7 +22,7 @@
 static __inline void
 grub_cpu_idle (void)
 {
-  /* FIXME: this can't work untill we handle interrupts.  */
+  /* FIXME: this can't work until we handle interrupts.  */
 /*  __asm__ __volatile__ ("hlt"); */
 }
 
index e617196b8fd433227d8c2188083d749839815978..be395ca7ffd7ef91ab464c3a6e7d8188287e0f3b 100644 (file)
@@ -22,7 +22,7 @@
 #include <grub/err.h>
 #include <grub/types.h>
 
-/* Video color in hardware dependant format.  Users should not assume any
+/* Video color in hardware dependent format.  Users should not assume any
    specific coding format.  */
 typedef grub_uint32_t grub_video_color_t;
 
index 62d5c720cba39403e1a59532ec039a0f7ef0b797..0fada6cc5e2b5b7f3e0833b67b683902d03293a7 100644 (file)
--- a/io/gzio.c
+++ b/io/gzio.c
@@ -56,9 +56,9 @@
 /* The state stored in filesystem-specific data.  */
 struct grub_gzio
 {
-  /* The underlyding file object.  */
+  /* The underlying file object.  */
   grub_file_t file;
-  /* The offset at which the data starts in the underlyding file.  */
+  /* The offset at which the data starts in the underlying file.  */
   grub_off_t data_offset;
   /* The type of current block.  */
   int block_type;
@@ -79,7 +79,7 @@ struct grub_gzio
   unsigned long bb;
   /* The bits in the bit buffer.  */
   unsigned bk;
-  /* Ths sliding window in uncompressed data.  */
+  /* The sliding window in uncompressed data.  */
   grub_uint8_t slide[WSIZE];
   /* Current position in the slide.  */
   unsigned wp;
index 6696c18220de78e2feaadd605e326e82f326fa00..6ab10e2a1e6c124244447b01ac44f37ef8fff008 100644 (file)
@@ -53,7 +53,7 @@ grub_env_hashval (const char *s)
 {
   unsigned int i = 0;
 
-  /* XXX: This can be done much more effecient.  */
+  /* XXX: This can be done much more efficiently.  */
   while (*s)
     i += 5 * *(s++);
 
index 4267f5b7dfbd26246e590669919466dbd213eb71..c1da148aad09476343adc2e1031fa7db8c98c8fe 100644 (file)
@@ -1089,7 +1089,7 @@ xsmap:
  * character and the attribute, and restore the current position.
  *
  * The reason why this is so complicated is that there is no easy way to
- * get the height of the screen, and the TELETYPE OUPUT BIOS call doesn't
+ * get the height of the screen, and the TELETYPE OUTPUT BIOS call doesn't
  * support setting a background attribute.
  */
 FUNCTION(grub_console_real_putchar)
index 4cb846d5ea62d7df48f724b8233fc13f2048b499..9ac88f63d0c1b721a76287dd3db002b6897d5c73 100644 (file)
@@ -576,7 +576,7 @@ grub_divmod64 (grub_uint64_t n, grub_uint32_t d, grub_uint32_t *r)
   unsigned long long q = 0;
   unsigned m = 0;
 
-  /* Skip the slow computation, if 32-bit arithmetics are possible.  */
+  /* Skip the slow computation if 32-bit arithmetic is possible.  */
   if (n < 0xffffffff)
     {
       if (r)
index 736039e10e3b46651f47598f95d7d95c583a5502..b56c4ab6f31121a01ca6d23b59a5c6f45063550b 100644 (file)
--- a/kern/mm.c
+++ b/kern/mm.c
@@ -164,7 +164,7 @@ grub_mm_init_region (void *addr, grub_size_t size)
   r->size = (h->size << GRUB_MM_ALIGN_LOG2);
 
   /* Find where to insert this region. Put a smaller one before bigger ones,
-     to prevent fragmentations.  */
+     to prevent fragmentation.  */
   for (p = &base, q = *p; q; p = &(q->next), q = *p)
     if (q->size > r->size)
       break;
index ab7ae660f2c26c4a13aa089d3a7bdb38b38cd601..c9d13f059ca8c601af6501d1177f26e3750c3512 100644 (file)
@@ -88,7 +88,7 @@ grub_ieee1275_find_options (void)
             3rd party updates which fix the partition bugs are common, and for
             some reason their fixes aren't being merged into trunk.  So for
             example we know that 1.2 and 1.3 are broken, but there's 1.2.99
-            and 1.3.99 which are known good (and appliing this workaround
+            and 1.3.99 which are known good (and applying this workaround
             would cause breakage). */
          if (!grub_strcmp (tmp, "1.0")
              || !grub_strcmp (tmp, "1.1")
index b8207b028a415c7a681a21d2f1447eb82e045287..d8f7189afed6a5df8dd8ebf40d10a4ee31540504 100644 (file)
@@ -1,4 +1,4 @@
-/*  openfw.c -- Open firmware support funtions.  */
+/*  openfw.c -- Open firmware support functions.  */
 /*
  *  GRUB  --  GRand Unified Bootloader
  *  Copyright (C) 2003, 2004, 2005, 2007 Free Software Foundation, Inc.
@@ -159,7 +159,7 @@ grub_err_t grub_available_iterate (int (*hook) (grub_uint64_t, grub_uint64_t))
   if (grub_ieee1275_get_property (memory, "available", available,
                                  sizeof available, 0))
     return grub_error (GRUB_ERR_UNKNOWN_DEVICE,
-                      "Couldn't examine /memory/available propery");
+                      "Couldn't examine /memory/available property");
 
   /* Decode each entry and call `hook'.  */
   i = 0;
index 5f2f20c08455fcb5997f004fc30f8de421e03d9b..03c6a66ecc3d6d883278ee1cd3f9647f788dfcd7 100644 (file)
@@ -1,4 +1,4 @@
-/*  openfw.c -- Open firmware support funtions.  */
+/*  openfw.c -- Open firmware support functions.  */
 /*
  *  GRUB  --  GRand Unified Bootloader
  *  Copyright (C) 2003,2004,2005,2007  Free Software Foundation, Inc.
index c7946e3048c7a3885dd77ffcc41fd73354fa8856..4462ddd59d29d9d3d75c2bd74cca11e0ce3eed37 100644 (file)
@@ -231,7 +231,7 @@ grub_script_execute_menuentry (struct grub_script_cmd *cmd)
       return grub_errno;
     }
 
/* XXX: When this fails, the memory should be free'ed?  */
   return grub_normal_menu_addentry (title, script,
                                    cmd_menuentry->sourcecode);
 }
index 053a770a1338c14326d04b1e10155f8a053376ef..b72b4ee47bec6eaea4bc7c8d23b60131b980bb2a 100644 (file)
@@ -254,7 +254,7 @@ grub_script_yylex2 (YYSTYPE *yylval, struct grub_parser_param *parsestate)
            break;
 
          /* If the string is not quoted or escaped, stop processing
-            when a special token was found.  It will be recognised
+            when a special token was found.  It will be recognized
             next time when this function is called.  */
          if (newstate == GRUB_PARSER_STATE_TEXT
              && state->state != GRUB_PARSER_STATE_ESC)
index f754b85d23447c492b9a8561abc376c5d632d112..6bb947eedb93dc78659c472010e1c3f2c1d31759 100644 (file)
@@ -335,7 +335,7 @@ insert_string (struct screen *screen, char *s, int update)
          int size;
          int orig_num, new_num;
 
-         /* Find a string delimitted by LF.  */
+         /* Find a string delimited by LF.  */
          p = grub_strchr (s, '\n');
          if (! p)
            p = s + grub_strlen (s);
index 02fe8c55ce06ee4a3a6b7350d635cab599061ea5..19cd1bd09cde3f39fdeb765409f78a9a907907a4 100644 (file)
@@ -92,7 +92,7 @@ argument:     GRUB_PARSER_TOKEN_VAR
                    $$ = grub_script_arg_add (state, 0, GRUB_SCRIPT_ARG_TYPE_STR, $1);
                  }
 /* XXX: Currently disabled to simplify the parser.  This should be
-   parsed by yet another parser for readibility.  */
+   parsed by yet another parser for readability.  */
 /*             | argument GRUB_PARSER_TOKEN_VAR */
 /*               { */
 /*                 $$ = grub_script_arg_add ($1, GRUB_SCRIPT_ARG_TYPE_VAR, $2); */
@@ -163,14 +163,14 @@ commands: command '\n'
    change any stuff because it might seem like a fun thing to do!
    Special care was take to make sure the mid-rule actions are
    executed on the right moment.  So the `commands' rule should be
-   recognised after executing the `grub_script_mem_record; and before
+   recognized after executing the `grub_script_mem_record; and before
    `grub_script_mem_record_stop'.  */
 function:      "function" GRUB_PARSER_TOKEN_NAME
                  { 
                    grub_script_lexer_ref (state->lexerstate);
                  } newlines '{'
                  { 
/* The first part of the function was recognised.
                       Now start recording the memory usage to store
                       this function.  */
                    state->func_mem = grub_script_mem_record (state);
index 475a03a499804a6902ce8e9027c6e07f686e70e8..5169e4949d8e4a547047d3fef190deedf8adc8cb 100644 (file)
 
 /* It is not possible to deallocate the memory when a syntax error was
    found.  Because of that it is required to keep track of all memory
-   allocations.  The memory is free'ed in case of an error, or
+   allocations.  The memory is freed in case of an error, or
    assigned to the parsed script when parsing was successful.  */
 
 /* XXX */
 
 /* In case of the normal malloc, some additional bytes are allocated
    for this datastructure.  All reserved memory is stored in a linked
-   list so it can be easily free'ed.  The original memory can be found
+   list so it can be easily freed.  The original memory can be found
    from &mem.  */
 struct grub_script_mem
 {
@@ -230,7 +230,7 @@ grub_script_create_cmdmenu (struct grub_parser_param *state,
   cmd = grub_script_malloc (state, sizeof (*cmd));
   cmd->cmd.exec = grub_script_execute_menuentry;
   cmd->cmd.next = 0;
/* XXX: Check if this memory is properly free'ed.  */
   cmd->sourcecode = sourcecode;
   cmd->title = title;
   cmd->options = options;
index a136d81672cf56e36cbb1e537536048c6e4254cb..9db5e0e457697e159502a553f3b7433979825e22 100644 (file)
@@ -27,8 +27,8 @@
 #define LINUX_SWAP_MAGIC   grub_cpu_to_le32 (0xdeafab1e)
 #define LINUX_MAP_ENTRIES  (512 / 12)
 
-#define NONADFS_PARTITON_TYPE_LINUX 9
-#define NONADFS_PARTITON_TYPE_MASK 15
+#define NONADFS_PARTITION_TYPE_LINUX 9
+#define NONADFS_PARTITION_TYPE_MASK 15
 
 struct grub_acorn_boot_block
 {
@@ -65,7 +65,7 @@ acorn_partition_map_find (grub_disk_t disk, struct linux_part *m,
   if (err)
     return err;
 
-  if ((boot.flags & NONADFS_PARTITON_TYPE_MASK) != NONADFS_PARTITON_TYPE_LINUX)
+  if ((boot.flags & NONADFS_PARTITION_TYPE_MASK) != NONADFS_PARTITION_TYPE_LINUX)
     goto fail;
 
   for (i = 0; i != 0x1ff; ++i)
index 46376f5ab589d0a0745d53ad39b2731b6ff6b616..b05a2e2a30012eaeaeb0013cb29839509eae3989 100644 (file)
@@ -110,13 +110,13 @@ sun_partition_map_iterate (grub_disk_t disk,
                      (char *) &block) == GRUB_ERR_NONE)
     {
       if (GRUB_PARTMAP_SUN_MAGIC != grub_be_to_cpu16 (block.magic))
-       grub_error (GRUB_ERR_BAD_PART_TABLE, "not a sun partiton table");
+       grub_error (GRUB_ERR_BAD_PART_TABLE, "not a sun partition table");
       
       if (! grub_sun_is_valid (&block))
        grub_error (GRUB_ERR_BAD_PART_TABLE, "invalid checksum");
       
       /* Maybe another error value would be better, because partition
-        table _is_ recognised but invalid.  */
+        table _is_ recognized but invalid.  */
       for (partnum = 0; partnum < GRUB_PARTMAP_SUN_MAX_PARTS; partnum++)
        {
          struct grub_sun_partition_descriptor *desc;
index 0ace430a92b7ced41b00ea3edd5b7013a755cc6b..f1144bfd08490a34fa6e409522fb12f66954e1a2 100644 (file)
@@ -349,7 +349,7 @@ grub_gfxterm_init (void)
           
           /* Try out video mode.  */
           
-          /* If we have 8 or less bits, then assuem that it is indexed color mode.  */
+          /* If we have 8 or less bits, then assume that it is indexed color mode.  */
           if ((depth <= 8) && (depth != -1))
             flags |= GRUB_VIDEO_MODE_TYPE_INDEX_COLOR;
 
@@ -399,7 +399,7 @@ grub_gfxterm_init (void)
     {
       /* No gfxmode variable set, use defaults.  */
       
-      /* If we have 8 or less bits, then assuem that it is indexed color mode.  */
+      /* If we have 8 or less bits, then assume that it is indexed color mode.  */
       if ((depth <= 8) && (depth != -1))
         flags |= GRUB_VIDEO_MODE_TYPE_INDEX_COLOR;
 
index 1fc2be1376ff9e640fc5d1dbb2fe0db53332c985..762d4e9c0a148587346bc8bb25829d33035411f9 100644 (file)
@@ -88,7 +88,7 @@ serial_hw_fetch (void)
   return -1;
 }
 
-/* Put a chararacter.  */
+/* Put a character.  */
 static void
 serial_hw_put (const int c)
 {
@@ -273,7 +273,7 @@ serial_hw_init (void)
 {
   unsigned char status = 0;
 
-  /* Turn off the interupt.  */
+  /* Turn off the interrupt.  */
   grub_outb (0, serial_settings.port + UART_IER);
 
   /* Set DLAB.  */
index d14ad89cad9814216db4776ba472b5d471aae3eb..c1811a846d63d5a8117b8eaaacbbef35fc157168 100644 (file)
@@ -54,7 +54,7 @@ struct grub_colored_char
 
 struct grub_virtual_screen
 {
-  /* Dimensions of the virual screen.  */
+  /* Dimensions of the virtual screen.  */
   grub_uint32_t width;
   grub_uint32_t height;
 
@@ -77,7 +77,7 @@ struct grub_virtual_screen
   grub_uint8_t fg_color;
   grub_uint8_t bg_color;
 
-  /* Text buffer for virual screen. Contains (columns * rows) number
+  /* Text buffer for virtual screen. Contains (columns * rows) number
      of entries.  */
   struct grub_colored_char *text_buffer;
 };
@@ -376,7 +376,7 @@ scroll_up (void)
       virtual_screen.text_buffer[i].index = 0;
     }
 
-  /* Scroll frambuffer with one line to up.  */
+  /* Scroll framebuffer with one line to up.  */
   grub_memmove (framebuffer,
                 framebuffer
                 + bytes_per_scan_line * virtual_screen.char_height,
index accb8fcc4445da273c7c2761ab336e8ded37fa19..c80c335c5b048b6bc47d2e398d61ec58e0b1c1a5 100644 (file)
@@ -425,7 +425,7 @@ grub_util_biosdisk_read (grub_disk_t disk, grub_disk_addr_t sector,
 #ifdef __linux__
   if (sector == 0 && size > 1)
     {
-      /* Work around a bug in linux's ez remapping.  Linux remaps all
+      /* Work around a bug in Linux ez remapping.  Linux remaps all
         sectors that are read together with the MBR in one read.  It
         should only remap the MBR, so we split the read in two 
         parts. -jochen  */
index f4dc66a1187d17f1ade0f662de9bd3d0c0428973..e2620a81f2c7de7445097824a2ef0eb25a73f3eb 100644 (file)
@@ -257,7 +257,7 @@ main (int argc, char *argv[])
   /* First, get defined symbols.  */
   read_defined_symbols (stdin);
 
-  /* Second, find the dependecies.  */
+  /* Second, find the dependencies.  */
   for (i = 1; i < argc; i++)
     {
       FILE *fp;
index 3e1dda6edf604dfe940fe829ee2eae9de9d7cef8..63ff61e084af138822e3e69f8fbeb2899aed0eeb 100644 (file)
@@ -61,7 +61,7 @@ Install GRUB on your EFI partition.
   --no-floppy             do not probe any floppy drive
   --recheck               probe a device map even if it already exists
 
-grub-install copies GRUB images into the DIR/boot directory specfied by
+grub-install copies GRUB images into the DIR/boot directory specified by
 --root-directory.
 
 Report bugs to <bug-grub@gnu.org>.
index a2d9c5b43e2fdde30c53c736f91c218a8e31fabd..e705086c62087d0a978d0ceccbaf3b358341d1e6 100644 (file)
@@ -69,7 +69,7 @@ Install GRUB on your drive.
 
 INSTALL_DEVICE can be a GRUB device name or a system device filename.
 
-grub-install copies GRUB images into the DIR/boot directory specfied by
+grub-install copies GRUB images into the DIR/boot directory specified by
 --root-directory, and uses grub-setup to install grub into the boot
 sector.
 
index 2f917829c653a78acdd0625baedd9d1e16b4e208..827b827f90cd126453b96826b4367c5cbbaf8207 100644 (file)
@@ -65,7 +65,7 @@ Install GRUB on your drive.
   --grub-probe=FILE       use FILE as grub-probe
   --no-nvram              don't update the boot-device NVRAM variable
 
-grub-install copies GRUB images into the DIR/boot directory specfied by
+grub-install copies GRUB images into the DIR/boot directory specified by
 --root-directory, and uses nvsetenv to set the Open Firmware boot-device
 variable.
 
index f9f69b97fd357966e6a68dcd194f0766215af04e..f60e6287c564450ac9cac7f918be2f95e1b240f9 100644 (file)
@@ -69,7 +69,7 @@ if test -e ${grub_prefix}/device.map ; then : ; else
   grub-mkdevicemap
 fi
 
-# Device containing our userland.  Typicaly used for root= parameter.
+# Device containing our userland.  Typically used for root= parameter.
 GRUB_DEVICE="`grub-probe --target=device /`"
 
 # Filesystem for the device containing our userland.  Used for stuff like
@@ -135,7 +135,7 @@ cat << EOF
 #
 # DO NOT EDIT THIS FILE
 #
-# It is automaticaly generated by $0 using templates
+# It is automatically generated by $0 using templates
 # from ${update_grub_dir} and settings from ${sysconfdir}/default/grub
 #
 EOF
index 5aded70dedb9875f5e2355503334661f22eb576b..8d4fe16aa5b083e01f3d763417fbe57ebee27016 100644 (file)
@@ -606,7 +606,7 @@ grub_video_vbe_set_viewport (unsigned int x, unsigned int y,
                              unsigned int width, unsigned int height)
 {
   /* Make sure viewport is withing screen dimensions.  If viewport was set
-     to be out of the reqion, mark its size as zero.  */
+     to be out of the region, mark its size as zero.  */
   if (x > active_mode_info.x_resolution)
     {
       x = 0;
@@ -766,7 +766,7 @@ grub_video_vbe_unmap_color (struct grub_video_i386_vbeblit_info * source,
   if ((mode_info->mode_type 
        & GRUB_VIDEO_MODE_TYPE_INDEX_COLOR) != 0)
     {
-      /* If we have out of bounds color, return trasnparent black.  */
+      /* If we have an out-of-bounds color, return transparent black.  */
       if (color > 255)
         {
           *red = 0;
@@ -958,7 +958,7 @@ grub_video_vbe_blit_glyph (struct grub_font_glyph * glyph,
   return GRUB_ERR_NONE;
 }
 
-/* NOTE: This function assumes that given coordiantes are within bounds of 
+/* NOTE: This function assumes that given coordinates are within bounds of 
    handled data.  */
 static void
 common_blitter (struct grub_video_i386_vbeblit_info *target,
@@ -1435,7 +1435,7 @@ grub_video_vbe_create_render_target (struct grub_video_render_target **result,
   target->mode_info.bpp = 32;
   target->mode_info.bytes_per_pixel = 4;
   target->mode_info.pitch = target->mode_info.bytes_per_pixel * width;
-  target->mode_info.number_of_colors = 256; /* Emulated paletted.  */
+  target->mode_info.number_of_colors = 256; /* Emulated palette.  */
   target->mode_info.red_mask_size = 8;
   target->mode_info.red_field_pos = 0;
   target->mode_info.green_mask_size = 8;
index 6acb5920b9b8ff8eb1ee651eb8cb54342a435cba..7b944b09ff49ecaf7c68c34a1d4c23d46d6a7e10 100644 (file)
@@ -327,7 +327,7 @@ grub_video_reader_tga (struct grub_video_bitmap **bitmap,
      ID from end of file, but we really don't care about that as we are
      not going to support developer area & extensions at this point.  */
 
-  /* Read TGA header from begining of file.  */
+  /* Read TGA header from beginning of file.  */
   if (grub_file_read (file, (char*)&header, sizeof (header)) 
       != sizeof (header))
     {
@@ -440,7 +440,7 @@ grub_video_reader_tga (struct grub_video_bitmap **bitmap,
         }
     }
 
-  /* If there were loading proble, destroy bitmap.  */
+  /* If there was a loading problem, destroy bitmap.  */
   if (grub_errno != GRUB_ERR_NONE)
     {
       grub_video_bitmap_destroy (*bitmap);
index 5d01f0da540cf5fc375338110d26577cd2d2a794..bd434462ef67a30c73ccfc07bdd4276c46cc9543 100644 (file)
@@ -20,7 +20,7 @@
 #include <grub/types.h>
 #include <grub/dl.h>
 
-/* The list of video adapters registerd to system.  */
+/* The list of video adapters registered to system.  */
 static grub_video_adapter_t grub_video_adapter_list;
 
 /* Active video adapter.  */
@@ -112,7 +112,7 @@ grub_video_setup (unsigned int width, unsigned int height,
                      "Can't locate valid adapter for mode");
 }
 
-/* Restore back to initial mode (where applicaple).  */
+/* Restore back to initial mode (where applicable).  */
 grub_err_t
 grub_video_restore (void)
 {
@@ -231,7 +231,7 @@ grub_script_execute_menuentry (struct grub_script_cmd *cmd)
     }
 
-  /* XXX: When this fails, the memory should be free'ed?  */
+  /* XXX: When this fails, the memory should be freed?  */
   return grub_normal_menu_addentry (title, script,
                                    cmd_menuentry->sourcecode);
@@ -163,14 +163,14 @@ commands: command '\n'
                  } newlines '{'
                  { 
-                   /* The first part of the function was recognised.
+                   /* The first part of the function was recognized.
                       Now start recording the memory usage to store
                       this function.  */
@@ -230,7 +230,7 @@ grub_script_create_cmdmenu (struct grub_parser_param *state,
   cmd->cmd.exec = grub_script_execute_menuentry;
   cmd->cmd.next = 0;
-  /* XXX: Check if this memory is properly free'ed.  */
+  /* XXX: Check if this memory is properly freed.  */
   cmd->sourcecode = sourcecode;
   cmd->title = title;